#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-9KapuNgZOtOK0LC0IRaU6f
key:                  coinbase-pro-0.9.3.2-9KapuNgZOtOK0LC0IRaU6f
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  9406937b2893d1f0f407c74e09e1268d
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-9KapuNgZOtOK0LC0IRaU6f
depends:
    HsOpenSSL-0.11.7.9-3vrZadETao5JtXy1jmJ1qb
    aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu
    aeson-casing-0.2.0.0-GNUTNAQUBoK4nIayveqlik
    async-2.2.6-HVFcnXCzrULJJSPrXugzlh base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-EBDtRqQVOEGOCEV6f2EDc exceptions-0.10.7
    http-api-data-0.6.1-ECeO0KZU1IgGCYQI58Pc96
    http-client-0.7.19-7npayQWK93786YkcsXS9Bz
    http-client-tls-0.3.6.4-AoMgZkRCYiu1L0w7n4Ap42
    http-streams-0.8.9.9-CzCK67Uk7RvImq20cQq2hM
    http-types-0.12.4-DdbAmHNhx8C4vBT5NO2sZU
    io-streams-1.5.2.2-3XQZ4sVPiLzDnpAKIUa1PE
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-5QGUGxzwH322yW8TioI43L
    servant-0.20.3.0-1NKOYzJUhf5EjKxUXsMldk
    servant-client-0.20.3.0-H7H6J4SxKreI2b0Oc2nMYE
    servant-client-core-0.20.3.0-GEAb6pZtVD03pYMkGFpjhY
    tasty-1.5.2-FiRZ1IWcSZ79yf7Nf1HVSK
    tasty-hunit-0.10.2-DbQ4UVIWzUHBBnBOX2iDZK text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-6I6kBlv1FN7KZLfRoMq5fY
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu
    uuid-1.3.16.1-907nm4R9lNz4H1OdRyxaGu
    vector-0.13.2.0-E81GJWrGuCo4SgJOIsfBQo
    websockets-0.12.7.3-83xZAGvGC14EtzF3TOJddo
    wuss-2.0.1.7-8XO3JhNNPTJAgx76G5rSvs

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

